from django.shortcuts import render
from rest_framework.response import Response
from rest_framework.decorators import api_view
from rest_framework import status
from db_config.db import database
from pymongo import MongoClient
import re
from nltk.corpus import stopwords
import nltk
from api import helpers
#import helpers


def speices_count(req_type):
    response_dict = dict()
    if req_type == "plant" or req_type == "butterfly_moth" or req_type == "mammal" or req_type == "amphibian_reptile" or req_type == "fish" or req_type == "bird":
        banner_images = database["banner_images"].find_one(
            {"type": req_type}, {"_id": 0, "type": 0})
        number_of_species = (database["biodiversity"].find(
            {"type": req_type}, {"_id": 0}).distinct("taxonomy.species"))
        number_of_family =(database["biodiversity"].find(
            {"type": req_type}, {"_id": 0}).distinct("taxonomy.family"))
        number_of_genus = (database["biodiversity"].find(
            {"type": req_type}, {"_id": 0}).distinct("taxonomy.genus"))
        number_of_group = (database["biodiversity"].find(
            {"type": req_type}, {"_id": 0}).distinct("taxonomy.group"))
        data_count = [{"name": "Group",  "count": len(number_of_group) , "id":"group"},
                     {"name": "Family",  "count":len(number_of_family),  "id":"family"},
                     {"name": "Genus",   "count": len(number_of_genus),  "id":"genus"},
                     {"name": "Species", "count":  len(number_of_species), "id":"species"}]         
        response_dict["specie_count"] = data_count
        response_dict["banner_info"] = banner_images["home_banner"]
        response_dict["banner_images"] = banner_images["banner_images"]
        response_dict["heading"] = banner_images["heading"]
        return response_dict

 



def speices_list(req_type,req_count):
    species_data = database["biodiversity"].find(
            {"type": req_type}, {"_id": 0}).sort("taxonomy.species",1)
    
    
    heading = database["banner_images"].find_one(
            {"type": req_type}, {"_id": 0, "type": 0})
    data = list()
    specie_data=dict()
    if req_type == "plant"   or req_type == "amphibian_reptile" or req_type == "fish":    
        specie_data["name"]= heading["heading"][0]
        specie_data["type"]=req_type
        for i in species_data:
            data_dict = dict()
            thumnail = list()
            data_dict["id"] = i["id"]
            species_name = i["taxonomy"]["species"]
            listToStr = ' '.join([str(element) for element in species_name])
            data_dict["species_name"] = [' '.join(listToStr.split()[:2])]   #first two word of a specie will return
            data_dict["family"] = i["taxonomy"]["family"]
            data_dict["genus"] = i["taxonomy"]["genus"]
            thumnail.append(i["specie_images"]["thumbnail"])
            data_dict["thumbnail"] = thumnail    
            data.append(data_dict)  
        specie_data["species_list"]=data[:14] if req_count=="yes" else data
        return specie_data
    elif req_type == "mammal":    
        mammal_data = database["biodiversity"].find(
            {"type": req_type}, {"_id": 0}).sort("common_names.english",1)
        specie_data["name"]= heading["heading"][0]
        specie_data["type"]=req_type
        for i in mammal_data:
            data_dict = dict()
            thumnail = list()
            data_dict["id"] = i["id"]
            name=i["common_names"]["english"][0]
            english_split=name.split(",")
            species_name=english_split[0]
            data_dict["common_name"]= [' '.join(species_name.split()[:2])]
            data_dict["species"] = i["taxonomy"]["species"]
            #data_dict["family"] = i["taxonomy"]["family"]
            data_dict["genus"] = i["taxonomy"]["genus"]
            thumnail.append(i["specie_images"]["thumbnail"])
            data_dict["thumbnail"] = thumnail    
            data.append(data_dict)  
        specie_data["species_list"]=data[:14] if req_count=="yes" else data
        return specie_data
    elif  req_type == "butterfly_moth"   or req_type == "bird":  
        species_data = database["biodiversity"].find(
            {"type": req_type}, {"_id": 0}).sort("taxonomy.common_name",1)  
        specie_data["name"]= heading["heading"][0]
        specie_data["type"]=req_type
        for i in species_data:
            data_dict = dict()
            thumnail = list()
            data_dict["id"] = i["id"]
            species_name = i["taxonomy"]["common_name"]
            listToStr = ' '.join([str(element) for element in species_name])
            data_dict["common_name"] = [' '.join(listToStr.split()[:2])]
            data_dict["species"] = i["taxonomy"]["species"]
           #data_dict["family"] = i["taxonomy"]["family"]
            data_dict["genus"] = i["taxonomy"]["genus"]
            thumnail.append(i["specie_images"]["thumbnail"])
            data_dict["thumbnail"] = thumnail    
            data.append(data_dict)  
        specie_data["species_list"]=data[:14] if req_count=="yes" else data
        return specie_data
    
def speices_detail(req_id,final_data):
    plant_data = database["biodiversity"].find_one(
        {'id': req_id}, {"_id": 0})
    detail_list = list()
    final_data["type"] = plant_data['type']
    banner_info = database['banner_images'].find_one(
        {'type': final_data['type']}, {"_id": 0})
    final_data["name"]=banner_info["heading"][0]
    for key, value in plant_data.items():  # specie details
        if key != 'id' and key != 'type' and key != 'banner_info' and key != 'other_sources' and key != 'specie_images' and type(value) != list:
            banner_information = dict()
            if key == "taxonomy":
                banner_information['species'] = value["species"][0]
                banner_information['genus'] = value['genus'][0]
                banner_information['family'] = value['family'][0]
                banner_information["banner_images"] = banner_info['banner_images']
                final_data['banner_information'] = banner_information
            detail_list_data = dict()
            updated_key = key.replace("_", " ")
            detail_list_data["name"] = updated_key.capitalize()
            nested_detail_list = list()
            data_new = dict()
            for key, value in value.items():
                detail_dict = dict()
                updated_key = key.replace("_", " ")
                if updated_key == "flowering and fruiting":
                    updated_key = "Flowering and Fruiting"
                    detail_dict["name"] = updated_key
                    detail_dict['data'] = value
                elif updated_key == "iucn red list":
                    updated_key = "IUCN Red List"
                    detail_dict["name"] = updated_key
                    detail_dict['data'] = value
                elif updated_key == "wildlife protection act 1972" or updated_key == "cites category":
                    detail_dict["name"] = updated_key.title()
                    detail_dict['data'] = value
                else:
                    detail_dict["name"] = updated_key.capitalize()
                    detail_dict['data'] = value
                nested_detail_list.append(detail_dict)
                detail_list_data["data"] = nested_detail_list
            data_new["element"] = detail_list_data
            detail_list.append(data_new)
        elif key == "references":
            detail_list_data = dict()
            data_new = dict()
            detail_list_data["name"] = key.capitalize()
            detail_list_data['data'] = value
            data_new["element"] = detail_list_data
            detail_list.append(data_new)
            final_data['specie_data'] = detail_list
        elif key == "other_sources":
            specie_hyperlink = dict()
            specie_hyperlink["other_sources"] = value
            specie_hyperlink["sources_icon_image"] = banner_info["hyperlink_images"]
            final_data["specie_hyperlink"] = specie_hyperlink
        elif key == "specie_images":
            final_data["specie_images"] = value
    return final_data


def species_hier(req_id, final_data):
    plant_data = database["biodiversity"].find_one(
        {'id': req_id}, {"_id": 0})
    data = dict()
    data["type"] = plant_data['type']
    banner_info = database['banner_images'].find_one(
        {'type': data['type']}, {"_id": 0})
    # final_data=dict()
    hier_list = list()
    for key, value in plant_data.items():  # specie hierarchy structure
        if key != 'id' and key != 'type' and key != 'other_sources' and key != 'banner_info' and key != 'specie_images' and type(value) != list:
            hier_list_data = dict()
            updated_key = key.replace("_", " ")
            hier_list_data["list_name"] = updated_key.capitalize()
            nested_list = list()
            for key in value:
                key_dict =dict()
                updated_key = key.replace("_", " ")
                key_dict["id"] =key
                key_dict["name"]=updated_key
                nested_list.append(key_dict)
                hier_list_data["list_ele"] = nested_list
            hier_list.append(hier_list_data)
        elif key == "references":
            hier_list_data = dict()
            hier_list_data["list_name"] = key.capitalize()
            hier_list_data["list_ele"] = list()
            hier_list.append(hier_list_data)
        data["hier_level"] = hier_list
        final_data["specie_hier"] = data
    return final_data


def bibliography_data(req_type, req_element):
    if len(req_type) != 0:
        if req_element == "amphibian and reptiles":
            req_element = "amphibian_and_reptiles"
        elif req_element == "fungi and lichen":
            req_element = "fungi_and_lichen"
        elif req_element == "environmental sciences":
            req_element ="environmental_sciences"
        elif req_element == "geology geography":
            req_element = "geology_geography"
        elif req_element == "political sciences":
            req_element ="political_sciences"
        bibliography = dict()
        data = req_element
        print(len(data))
        if len(data)>0:
            bibliography_data = database["bibliography"].find_one(
            {'type': req_type}, {"_id": 0, data: 1})
            data_list = bibliography_data[req_element]
        else:
            bibliography_data = list(database["bibliography"].find(
            {'type': req_type}, {"_id": 0}))
            bibliography_data=bibliography_data[0]
            for key,value in bibliography_data.items():
                data_list= value
                req_element =key
        #print(len(bibliography_data[req_element]))
        #print(bibliography_data[0])
        bibliography["element_name"] = req_element

        bibliography["element_data"] = data_list
    return bibliography

def bibliography_pagination(req_type, req_element,req_page):
    if len(req_type) != 0 and len(req_element) != 0:
        if req_element == "amphibian and reptiles":
            req_element = "amphibian_and_reptiles"
        elif req_element == "fungi and lichen":
            req_element = "fungi_and_lichen"
        bibliography = dict()
        data = req_element
        bibliography_data = database["bibliography"].find_one(
            {'type': req_type}, {"_id": 0, data: 1})
        #print(len(bibliography_data[req_element]))
        data_list = bibliography_data[req_element]
        new_list = [data_list[i:i+10] for i in range(0, len(data_list), 10)]
        #print(len(new_list))
        bibliography["page"] = req_page
        bibliography["total_pages"]=len(new_list)
        bibliography["element_name"] = req_element
        bibliography["element_data"] = new_list[int(req_page)]
    return bibliography


def bibliography_heir(req_type):
    if len(req_type) != 0:
        sidebar_data = list(database["bibliography"].find(
            {'type': req_type}, {"_id": 0}))
        response = dict()
        hierLevelList = list()
        sidebar_data=sidebar_data[0]  
        element_list = list()
        hier_dict =dict()
        for key,value in sidebar_data.items():
            element_dict = dict()
            if key !='type':
                sidebar_key_name = key.replace("_"," ")
                element_dict["id"]=key
                element_dict["name"]=sidebar_key_name
            element_list.append(element_dict)
            element_list =list(filter(None, element_list))
        list_name = req_type.replace("_"," ")
        hier_dict["list_name"] = list_name
        #print(len(element_list))
        #if len(element_list)>1:
        #    hier_dict["list_ele"]=element_list
        #else:
        #    hier_dict["list_ele"]=[]
        hier_dict["list_ele"]=element_list
        #print(element_list)    
        response['hier_level'] = [hier_dict]
    return response


def home_search(keyword, type, group):
    
    stopwords_list = set(stopwords.words('english'))
    keywords = list(map(lambda x: x.strip(), [
        i for i in keyword.strip().split("_=") if i and i not in stopwords_list]))
    regex_keywords = [re.compile(
        re.escape(i), re.IGNORECASE) for i in keywords]
    #print(database["biodiversity"].index_information())
    species = {"taxonomy.species": {"$in": regex_keywords}, "type": group} if group != '' else {
        "taxonomy.species": {"$in": regex_keywords}}
    synonyms = {
        "taxonomy.synonyms": {"$in": regex_keywords}, "type": group} if group != '' else {
        "taxonomy.synonyms": {"$in": regex_keywords}}
    common_name_english = {
        "common_names.english": {"$in": regex_keywords}, "type": group} if group != '' else {
        "common_names.english": {"$in": regex_keywords}}
    common_name_hindi = {
        "common_names.hindi": {"$in": regex_keywords}, "type": group} if group != '' else {
        "common_names.hindi": {"$in": regex_keywords}}
    common_name_ladakhi = {
        "common_names.ladakhi": {"$in": regex_keywords}, "type": group} if group != '' else {
        "common_names.ladakhi": {"$in": regex_keywords}}
    common_name = {
        "taxonomy.common_name": {"$in": regex_keywords}, "type": group} if group != '' else{
        "taxonomy.common_name": {"$in": regex_keywords}}
    
    res = list(database["biodiversity"].find(
        species, {"_id": 0}))
    
   
    if len(res) < 10:
        keyword_res = list(
            database["biodiversity"].find(common_name_english, {"_id": 0  }))
        res = res + [i for i in keyword_res if i not in res]
         
        keyword_res1 = list(
            database["biodiversity"].find(common_name_hindi, {"_id": 0}))
        res = res + [i for i in keyword_res1 if i not in res]
         
        keyword_res2 = list(
            database["biodiversity"].find(common_name_ladakhi, {"_id": 0}))
        res = res + [i for i in keyword_res2 if i not in res]
       
        keyword_res3 = list(
            database["biodiversity"].find(common_name, {"_id": 0}))
        res = res + [i for i in keyword_res3 if i not in res]
        
        keyword_res4 = list(
            database["biodiversity"].find(synonyms, {"_id": 0 }))
        res = res + [i for i in keyword_res4 if i not in res]   
        #print(res)
    data_list = list()
    for i in res:          #for loop is used to give response from res and all data will append in data_list
        #print(i)
        data = dict()
        data["id"] = i["id"]
        data["group"] = i["type"]
        data['group_trans']=i["type"]
        if data["group_trans"] == "amphibian_reptile" or  data["group_trans"]=="butterfly_moth" :
            new = data["group_trans"].replace("_", " ").title()
        else:
            new = data["group_trans"].title()
        data["specie"] = i["taxonomy"]["species"][0]  
        #if data["group"]== "plant" or data["group"]=="fish" or data["group"]=="mammal" or data["group"]=="amphibian_reptile":  
            
            #common_hindi=i["common_names"]["hindi"][0]     # here if condition is implemented because common_name field is not present in birds and butterflies
            #common_english=i["common_names"]["english"][0]
            #common_ladakhi=i["common_names"]["ladakhi"][0] 
            #ts=i["taxonomy"]["synonyms"]
            #search_synonyms=list()
            #for string in ts:  #here for loop is used to check whether the keyword is exist in synonyms
            #    if string.find(keyword.lower())!=-1 or  string.find(keyword)!=-1:
            #        search_synonyms.append(string)
            #if len(search_synonyms)>0:
            #    data["synoyms"]=search_synonyms
            #    
            #common_english_list=list()
            #common_hindi_list=list()
            #common_ladakhi_list=list()
            #hindi_split=common_hindi.split(",")  #in common name all data were present in a single string so here split function split each text in a individual string
            #english_split=common_english.split(",")
            #ladakhi_split=common_ladakhi.split(",")
            #
            #for string in hindi_split:         #here for loop is used to check whether the keyword is exist in common_name   
            #    if string.find(keyword.lower())!=-1 or  string.find(keyword)!=-1:
            #       common_hindi_list.append(string)
            #if len(common_hindi_list)>0:
            #    data["common_name"]=common_hindi_list[0]  
#
            #for string in english_split:      #here for loop is used to check whether the keyword is exist in common_name
            #    if string.find(keyword.lower())!=-1 or  string.find(keyword)!=-1:
            #        common_english_list.append(string)
            #if len(common_english_list)>0:
            #    data["common_name"]= common_english_list[0]  
#
            #for string in ladakhi_split:     #here for loop is used to check whether the keyword is exist in common_name
            #    if string.find(keyword.lower())!=-1 or  string.find(keyword)!=-1:
            #       common_ladakhi_list.append(string)
            #if len(common_ladakhi_list)>0:
            #    data["common_name"]=common_ladakhi_list[0] 
        #elif data["group"]== "bird" or   data["group"]=="butterfly_moth":
            #print(i)
            #data["specie"] = i["taxonomy"]["species"][0]
            #ts=i["taxonomy"]["synonyms"]
            ##synonyms=ts.replace(" ","")
            #search_synonyms=list()
            #for string in  ts:  #here for loop is used to check whether the keyword is exist in synonyms
            #    if string.find(keyword.lower())!=-1 or  string.find(keyword)!=-1:
            #        search_synonyms.append(string)
            #if len(search_synonyms)>0:
            #    data["synoyms"]=search_synonyms[0]
            #tc=i["taxonomy"]["common_name"]
            #common_name=list()
            #for string in tc:
            #    if string.find(keyword.lower())!=-1 or  string.find(keyword)!=-1:
            #        common_name.append(string)
            #if len(common_name)>0:
            #    data["common_name"]=common_name[0]
                #print(common_name)
  
        data["group_trans"] = new if group == '' else ''
        data_list.append(data)  
    return data_list
    #print(data_list)

def bibliography_search(search_key,req_type,req_element):
        stopwords_list = set(stopwords.words('english'))
        print(req_type)
        keywords = list(map(lambda x: x.strip(), [
        i for i in search_key.strip().split("_=") if i and i not in stopwords_list]))
        regex_keywords = [re.compile(
        re.escape(i), re.IGNORECASE) for i in keywords]
        print(keywords)
        res = helpers.bibliography_inner_search(regex_keywords,req_type)    
        bibliography_data = res[0]
         
        serach_result_list = list()
        for key in bibliography_data:
            serach_result_dict = dict()
            if bibliography_data[key]:
               result_search = [x for x in bibliography_data[key] if all(re.search("\\b" + w + "\\b" , x , re.IGNORECASE) for w in keywords)]
               serach_result_dict[key] = result_search
            if result_search!=[]:
                serach_result_list.append(serach_result_dict)

        key_list = list()
        key_ele = list()
        search_list =list()
        if len(req_element)==0:
            for key_data in serach_result_list:
                print(key_data)
                for i ,j in key_data.items():
                    name = i.replace("_"," ")
                    key_ele.append(name)
                key_dict = dict()   
                key_dict["search_key"] = search_key
                key_dict["key_elements"]= key_ele
            key_list.append(key_dict)
            return Response(status=status.HTTP_200_OK,
                                data={"data": key_list[0]})
        else:
            for key_data in serach_result_list:
                search_result = dict()
                for key,value in key_data.items():
                   name = req_element.replace(" ","_")
                   req_element =req_element.replace("_"," ")
                   if key== name:
                      search_result["name"] = req_element
                      search_result["data"] = value
                      search_list.append(search_result)
            return Response(status=status.HTTP_200_OK,
                                data={"data": search_list[0]})

def culture_heir(req_type):
    if len(req_type) != 0:
        sidebar_data = list(database["culture"].find(
            {'type': req_type}, {"_id": 0}))
        print(sidebar_data)
        response = dict()
        hierLevelList = list()
        sidebar_data=sidebar_data[0]  
        element_list = list()
        hier_dict =dict()
        for key,value in sidebar_data.items():
            element_dict = dict()
            if key !='type' and key!='image':
                if key == "rtsis_onpo_traditions_of_ladakh":
                    element_dict["id"]="rtsis_onpo_traditions_of_ladakh"
                    element_dict["name"]="rtsis & onpo traditions of ladakh"
                else:
                    sidebar_key_name = key.replace("_"," ")
                    element_dict["id"]=key
                    element_dict["name"]=sidebar_key_name
            element_list.append(element_dict)
            element_list =list(filter(None, element_list))
        list_name = req_type.replace("_"," ")
        hier_dict["list_name"] = list_name
        #print(len(element_list))
        #if len(element_list)>1:
        #    hier_dict["list_ele"]=element_list
        #else:
        #    hier_dict["list_ele"]=[]
        hier_dict["list_ele"]=element_list
        #print(element_list)    
        response['hier_level'] = [hier_dict]
    return response   

def culture_data(req_type, req_element):
    if len(req_type) != 0:
        bibliography = dict()
        data = req_element
        #print(len(data))
        if len(data)>0:
            bibliography_data = database["culture"].find_one(
            {'type': req_type}, {"_id": 0, data: 1})
            data_list = bibliography_data[req_element]
        else:
            bibliography_data = list(database["culture"].find(
            {'type': req_type}, {"_id": 0}))
            bibliography_data=bibliography_data[0]
            for key,value in bibliography_data.items():
                data_list= value
                req_element =key
        element_name = req_type.replace("_"," ")
        bibliography["element_name"] = element_name
        bibliography["element_data"] = data_list
    return bibliography

#wildlife department

def introduction_data(req_type, req_element):
    if len(req_type) != 0:
        bibliography = dict()
        data = req_element
        #print(len(data))
        if len(data)>0:
            bibliography_data = database["Introduction"].find_one(
            {'type': req_type}, {"_id": 0})
            data_list = bibliography_data[req_element]
        else:
            bibliography_data = list(database["Introduction"].find(
            {'type': req_type}, {"_id": 0}))
            bibliography_data=bibliography_data[0]
            for key,value in bibliography_data.items():
                data_list= value
                req_element =key
        element_name = req_type.replace("_"," ")
        bibliography["element_name"] = element_name
        bibliography["element_data"] = data_list
    return bibliography

# wildlife department

def wildlifeDepartment_heir(req_type):
    if len(req_type) != 0:
        sidebar_data = list(database["Introduction"].find(
            {'type': req_type}, {"_id": 0}))
        if sidebar_data!=[]:
            response = dict()
            hierLevelList = list()
            sidebar_data=sidebar_data[0]  
            element_list = list()
            hier_dict =dict()

            for key,value in sidebar_data.items():
                element_dict = dict()
                if key !='type' and key!='image':
                    if key == "wildlife_department":
                        element_dict["id"]="wildlife_department"
                        element_dict["name"]="wildlife_department"
                    else:
                        sidebar_key_name = key.replace("_"," ")
                        element_dict["id"]=key
                        element_dict["name"]=sidebar_key_name
                element_list.append(element_dict)
                element_list =list(filter(None, element_list))
            list_name = req_type.replace("_"," ")
            hier_dict["list_name"] = list_name
            hier_dict["list_ele"]=element_list 
            response['hier_level'] = [hier_dict]
        else:
            response = {"data":[],"success":True}
    return response   

#union territory of ladakh(data)

def unionterritory_data(req_type, req_element):
    if len(req_type) != 0:
        bibliography = dict()
        data = req_element
        #print(len(data))
        if len(data)>0:
            bibliography_data = database["unionterritoryofladakh"].find_one(
            {'type': req_type}, {"_id": 0})
            data_list = bibliography_data[req_element]
        else:
            bibliography_data = list(database["unionterritoryofladakh"].find(
            {'type': req_type}, {"_id": 0}))
            bibliography_data=bibliography_data[0]
            for key,value in bibliography_data.items():
                data_list= value
                req_element =key
        element_name = req_type.replace("_"," ")
        bibliography["element_name"] = element_name
        bibliography["element_data"] = data_list
    return bibliography

#union territory of ladakh hierarchy

def unionterritory_heir(req_type):
    if len(req_type) != 0:
        sidebar_data = list(database["unionterritoryofladakh"].find(
            {'type': req_type}, {"_id": 0}))
        print(sidebar_data)
        response = dict()
        hierLevelList = list()
        sidebar_data=sidebar_data[0]  
        element_list = list()
        hier_dict =dict()
        for key,value in sidebar_data.items():
            element_dict = dict()
            if key !='type' and key!='image':
                if key == "union_territory_of_ladakh":
                    element_dict["id"]="union_territory_of_ladakh"
                    element_dict["name"]="union_territory_of_ladakh"
                else:
                    sidebar_key_name = key.replace("_"," ")
                    element_dict["id"]=key
                    element_dict["name"]=sidebar_key_name
            element_list.append(element_dict)
            element_list =list(filter(None, element_list))
        list_name = req_type.replace("_"," ")
        hier_dict["list_name"] = list_name
        #print(len(element_list))
        #if len(element_list)>1:
        #    hier_dict["list_ele"]=element_list
        #else:
        #    hier_dict["list_ele"]=[]
        hier_dict["list_ele"]=element_list
        #print(element_list)    
        response['hier_level'] = [hier_dict]
    return response   


    





def taxonomy_names(req_id ,taxa_name , req_type,final_list):
    if req_id != "species":
                taxonomy_data = (database["biodiversity"].find(
            {"type": req_type}, {"_id": 0}).distinct(taxa_name))
                return Response(status=status.HTTP_200_OK,
                            data={"data":taxonomy_data})
                
    else:
        taxonomy_data = list(database["biodiversity"].find(
        {"type": req_type}, {"_id": 0}))
        for i in taxonomy_data:
            #print(i["taxonomy"]["common_name"])
            data_list = list()
            specie_dict = dict()
            specie_dict["id"] =i["id"]
            if req_type =="bird" or req_type=="butterfly_moth":
                #print(i["taxonomy"]["comman_name"])
                specie_dict["species_name"]=i["taxonomy"]["common_name"][0]
            elif req_type=="amphibian_reptile" or req_type=="mammal" or req_type=="fish":
                common_name =i["common_names"]["english"][0]
                charcter = ","
                if charcter in common_name:
                    first_name = common_name.index(",")
                    specie_dict["species_name"]= common_name[:first_name]
                else:
                    specie_dict["species_name"]= common_name
                    print(common_name)
            else:
                species_name = i["taxonomy"]["species"]
                listToStr = ' '.join([str(element) for element in species_name])
                specie_dict["species_name"]= [' '.join(listToStr.split()[:2])][0] 
            final_list.append(specie_dict)
            final_list=sorted(final_list, key = lambda i: (i['species_name']))
        return Response(status=status.HTTP_200_OK,
                            data={"data":final_list})
def group_names_count(taxa_name,req_name):
    final_dict = dict()
    response_list =list()
    number_of_family =(database["biodiversity"].find(
            {taxa_name:req_name}, {"_id": 0}).distinct("taxonomy.family"))
    number_of_genus =(database["biodiversity"].find(
            {taxa_name:req_name}, {"_id": 0}).distinct("taxonomy.genus"))
    number_of_species =(database["biodiversity"].find(
            {taxa_name:req_name}, {"_id": 0}).distinct("taxonomy.species"))    
    
    group_count = [{"name":"Group","count":1,"id":"group"},
                   {"name":"Family","count":len(number_of_family),"id":"family"},
                  {"name":"Genus","count":len(number_of_genus),"id":"genus"},
                  {"name":"Species","count":len(number_of_species),"id":"species"}]

    final_dict["specie_count"]=group_count
    final_dict["data"]=number_of_family
    response_list.append(final_dict)
    return Response(status=status.HTTP_200_OK,
                            data={"data":response_list[0]})
def family_names_count(taxa_name,req_name):
    final_dict =dict()
    response_list =list()
    number_of_genus =(database["biodiversity"].find(
            {taxa_name:req_name}, {"_id": 0}).distinct("taxonomy.genus"))
    number_of_species =(database["biodiversity"].find(
            {taxa_name:req_name}, {"_id": 0}).distinct("taxonomy.species"))    
   # print(number_of_species)
    family_count = [{"name":"Group","count":1,"id":"group"},
                   {"name":"Family","count":1,"id":"family"},
                  {"name":"Genus","count":len(number_of_genus),"id":"genus"},
                  {"name":"Species","count":len(number_of_species),"id":"species"}]

    final_dict["specie_count"]=family_count
    final_dict["data"]=number_of_genus
    response_list.append(final_dict)
    return Response(status=status.HTTP_200_OK,
                            data={"data":response_list[0]})

def genus_names_count(req_type,taxa_name,req_name,data,species,species_count,species_list):
    final_dict =dict()
    response_list = list()
    number_of_species =(database["biodiversity"].find(
            {taxa_name:req_name}, {"_id": 0}).distinct("taxonomy.species"))  
    #print(len(number_of_species)) 
    for i in data:  
        species_dict =dict()
        species_name = list() 
        species_dict["id"] =i["id"]
        if req_type =="plant":
            species_dict["species_name"]=i["taxonomy"]["species"][0]
        elif req_type =="bird"  or req_type=="butterfly_moth":
            species_dict["species_name"]=i["taxonomy"]["common_name"][0]
        elif req_type=="amphibian_reptile" or req_type=="mammal" or req_type=="fish":
            common_name =i["common_names"]["english"][0]
            charcter = ","
            if charcter in common_name:
                first_name = common_name.index(",")
                species_dict["species_name"]= common_name[:first_name]
            else:
                species_dict["species_name"]= common_name
               # print(common_name)
        species_name = i["taxonomy"]["species"][0]
        species_list.append(species_dict)
       
        species_count.append(species_name)
        species_count = list(filter(None, species_count))    
        [species.append(x) for x in species_count if x not in species]
        #print(species)
    group_count = [{"name":"Group","count":1,"id":"group"},
                   {"name":"Family","count":1,"id":"family"},
                  {"name":"Genus","count":1,"id":"genus"},
                  {"name":"Species","count":len(species),"id":"species"}]

    final_dict["specie_count"]=group_count
    final_dict["data"]=species_list
    response_list.append(final_dict)
    return Response(status=status.HTTP_200_OK,
                            data={"data": response_list[0]})
'''
def specie_hierarcy(request):
    try:
        req_id = request.GET.get("id", "")
        req_element = request.GET.get("element","")
        req_sub_element = request.GET.get("sub_element","")
        req_type = request.GET.get("type","")
        if req_type=="plant":
            if len(req_id) !=0 and  len(req_element)==0 and  len(req_sub_element)==0:
                plant_data = database["biodiversity"].find_one(
                    {'id': req_id},{"_id": 0})
                data=dict()
                data["type"]=plant_data['type']
                hier_list=list()
                for key,value in plant_data.items():
                    if key !='id' and key!= 'type' and key!='hyperlink' and type(value)!=str and type(value)!=list:
                        hier_list_data=dict()
                        updated_key=key.replace("_"," ")
                        hier_list_data["list_name"]=updated_key.capitalize()
                        nested_list=list()
                        for key in value:
                            updated_key=key.replace("_"," ")
                            nested_list.append(updated_key.capitalize() )
                            hier_list_data["list_ele"]=nested_list
                        hier_list.append(hier_list_data)
                    elif key=='iucn_status' or key=='nativity' or key=="references":
                        hier_list_data=dict()
                        updated_key=key.replace("_"," ")
                        if updated_key=="iucn status":
                            updated_key="IUCN Status"
                            hier_list_data["list_name"]=updated_key
                        else:
                            hier_list_data["list_name"]=updated_key.capitalize()
                        hier_list_data["list_ele"]=list()
                        hier_list.append(hier_list_data)
                    data["hier_level"]=hier_list
                return Response(status=status.HTTP_200_OK,
                                                  data={'data':data,'success': True})
            elif len(req_id) !=0 and  len(req_element)!=0 and  len(req_sub_element)!=0:
                data = req_element+'.'+req_sub_element
                plant_data = database["biodiversity"].find_one(
                    {'id': req_id},{"_id": 0,data:1})
                return Response(status=status.HTTP_200_OK,
                                                  data={'data': plant_data,'success': True})

            elif len(req_id) !=0 and  len(req_element)!=0 and  len(req_sub_element)==0:
                plant_data = database["biodiversity"].find_one(
                    {'id': req_id},{"_id": 0,req_element:1})
                return Response(status=status.HTTP_200_OK,
                                                  data={'data': plant_data,'success': True})

            return Response(status=status.HTTP_200_OK,
                                              data={'message':"Please check params",'success': True})
        elif req_type=='birds':
            if len(req_id) !=0 and  len(req_element)==0 and  len(req_sub_element)==0:
                bird_data = database["biodiversity"].find_one(
                    {'id': req_id},{"_id": 0})
                data=dict()
                data["type"]=bird_data['type']
                hier_list=list()
                for key,value in bird_data.items():
                    if key !='id' and key!= 'type' and key!='hyperlink':
                        hier_list_data=dict()
                        updated_key=key.replace("_"," ")
                        hier_list_data["list_name"]=updated_key.capitalize()
                        nested_list=list()
                        for key in value:
                            updated_key=key.replace("_"," ")
                            nested_list.append(updated_key.capitalize() )
                            hier_list_data["list_ele"]=nested_list
                        hier_list.append(hier_list_data)
                        data["hier_level"]=hier_list

                return Response(status=status.HTTP_200_OK,
                                              data={'data':data,'success': True})
            elif len(req_id) !=0 and  len(req_element)!=0 and  len(req_sub_element)==0:
                birds_data = database["biodiversity"].find_one(
                    {'id': req_id},{"_id": 0,req_element:1})
                return Response(status=status.HTTP_200_OK,
                                                  data={'data': birds_data,'success': True})

    except Exception as e:
        print(e)
        return Response(status=status.HTTP_404_NOT_FOUND, data={"message": str(e), "success": False})'''

